@@ -1,4 +1,5 @@
 import factory
+from feincms.module.page.models import Page
 
 from . import content, models
 
@@ -12,3 +13,9 @@ class DummyFactory(factory.DjangoModelFactory):
             return
         Content = models.Dummy.content_type_for(content.TestContent)
         Content.objects.create(parent=self, region='body')
+
+
+class PageFactory(factory.DjangoModelFactory):
+    FACTORY_FOR = Page
+
+    title = factory.Sequence('Page {}'.format)
